Package {GetLattesData}


Title: Reading Bibliometric Data from Lattes Platform
Version: 1.5.2
Description: A simple API for downloading and reading xml data directly from Lattes http://lattes.cnpq.br/.
Depends: R (≥ 4.1.0)
Imports: stringr, XML, dplyr, readr, stringdist, tools, lubridate, lifecycle, cli, xml2, tibble, janitor, purrr, readxl
License: GPL-2
Encoding: UTF-8
BugReports: https://github.com/msperlin/GetLattesData/issues
URL: https://github.com/msperlin/GetLattesData/
RoxygenNote: 7.3.2
Suggests: knitr, rmarkdown, testthat, ggplot2
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-09-21 21:02:57 UTC; msperlin
Author: Marcelo Perlin [aut, cre]
Maintainer: Marcelo Perlin <marceloperlin@gmail.com>
Repository: CRAN
Date/Publication: 2026-09-21 21:20:08 UTC

Reads zip files from Lattes

Description

This function reads zipped files from Lattes, giving as output a list with several dataframes

Usage

gld_get_lattes_data_from_zip(zip.files, field.qualis = NULL)

Arguments

zip.files

A vector with location of zip files downloaded from Lattes website

field.qualis

Area of Qualis to get Qualis journal rankings (default equals NULL). Eg. area.qualis <- 'ECONOMIA'

Value

Returns a list with two components:

tpesq

A dataframe with information about researchers

tpublic

A dataframe with information about publications

tsupervisions

A dataframe with information about all supervisions

Examples


# get files from pkg (you can download from other researchers in lattes website)
f.in <- system.file('extdata/3262699324398819.zip', package = 'GetLattesData')

# set qualis
field.qualis = 'ECONOMIA'

# get data
l.out <- gld_get_lattes_data_from_zip(f.in, field.qualis = field.qualis )

# print it
print(l.out$tpesq)
print(l.out$tpublic.published)

Reads xml data from lattes zip file

Description

Reads xml data from lattes zip file

Usage

gld_read_zip2(f_zip)

Arguments

f_zip

A (single) name of zip file containing a xml file

Value

A list with several items

Examples


f_in <- system.file('extdata/3262699324398819.zip', package = 'GetLattesData')
my_l <- gld_read_zip2(f_in)
my_l